@@ -2,7 +2,7 @@
 
 #############################################################################
 ##
-## Copyright (C) 2021 The Qt Company Ltd.
+## Copyright (C) 2022 The Qt Company Ltd.
 ## Contact: https://www.qt.io/licensing/
 ##
 ## This file is part of the provisioning scripts of the Qt Toolkit.
@@ -62,8 +62,9 @@ installPackages+=(pcre2-devel)
 installPackages+=(double-conversion-devel)
 installPackages+=(zstd)
 # EGL support
-installPackages+=(mesa-libEGL-devel)
-installPackages+=(mesa-libGL-devel)
+# mesa-libEGL-devel need to use older version than 22.1.5-2.el9 which cause Xorg to crash
+installPackages+=(mesa-libEGL-devel-21.3.4-2.el9)
+installPackages+=(mesa-libGL-devel-21.3.4-2.el9)
 installPackages+=(libxkbfile-devel)
 # Xinput2
 installPackages+=(libXi-devel)
@@ -78,6 +79,8 @@ installPackages+=(dbus-devel)
 installPackages+=(gstreamer1-plugins-bad-free)
 installPackages+=(gstreamer1-devel)
 installPackages+=(gstreamer1-plugins-base-devel)
+# yasm for QtMultimedia
+installPackages+=(yasm)
 # gtk3 style for QtGui/QStyle
 installPackages+=(gtk3-devel)
 # libusb1 for tqtc-boot2qt/qdb
@@ -85,13 +88,11 @@ installPackages+=(libusbx-devel)
 # speech-dispatcher-devel for QtSpeech, otherwise it has no backend on Linux
 installPackages+=(speech-dispatcher-devel)
 # Python 2 devel and pip. python-pip requires the EPEL repository to be added
-installPackages+=(python2-devel python2-pip)
+# Python 2 no longer supported
+# installPackages+=(python2-devel python2-pip)
 # Python 3 with python-devel, pip and virtualenv
-installPackages+=(python36)
-installPackages+=(python36-devel)
-# Python 3.8 for pyside. Qt for Python support for Python 3.6 will be deprecated in within pyside6.3
-installPackages+=(python38)
-installPackages+=(python38-devel)
+installPackages+=(python3)
+installPackages+=(python3-devel)
 # WebEngine
 installPackages+=(bison)
 installPackages+=(flex)
@@ -104,6 +105,7 @@ installPackages+=(libxshmfence-devel)
 installPackages+=(nspr-devel)
 installPackages+=(nss-devel)
 installPackages+=(python3-html5lib)
+installPackages+=(libstdc++-static)
 # For Android builds
 installPackages+=(java-11-openjdk-devel)
 # For receiving shasum
@@ -120,8 +122,9 @@ installPackages+=(libxslt-devel)
 # For building Wayland from source
 installPackages+=(libffi-devel)
 # QtWayland
-installPackages+=(mesa-libwayland-egl)
-installPackages+=(mesa-libwayland-egl-devel)
+# installPackages+=(mesa-libwayland-egl)
+# installPackages+=(mesa-libwayland-egl-devel)
+installPackages+=(libwayland-egl)
 installPackages+=(libwayland-client)
 installPackages+=(libwayland-cursor)
 installPackages+=(libwayland-server)
@@ -136,6 +139,9 @@ installPackages+=(xcb-util-image-devel)
 installPackages+=(xcb-util-keysyms-devel)
 installPackages+=(xcb-util-wm-devel)
 installPackages+=(xcb-util-renderutil-devel)
+installPackages+=(xcb-util-cursor)
+installPackages+=(xcb-util-cursor-devel)
+
 # ODBC support
 installPackages+=(unixODBC-devel)
 installPackages+=(unixODBC)
@@ -155,26 +161,32 @@ installPackages+=(gcc-c++)
 installPackages+=(make)
 # Open source VMware Tools
 installPackages+=(open-vm-tools)
+# nfs-utils is needed to make mount work with ci-files01
+installPackages+=(nfs-utils)
+
 
 sudo yum -y install "${installPackages[@]}"
 
-sudo ln -s /usr/bin/python2 /usr/bin/python
-
-sudo dnf -y module install nodejs:12
+sudo dnf install nodejs-16.14.0-4.el9_0 -y
+# Required by QtCore
+sudo dnf install 'perl(English)' -y
 
 # We shouldn't use yum to install virtualenv. The one found from package repo is not
 # working, but we can use installed pip
 sudo pip3 install --upgrade pip
 sudo pip3 install virtualenv wheel
 # Just make sure we have virtualenv to run with python3.8 -m virtualenv
-sudo python3.8 -m pip install virtualenv wheel
+sudo python -m pip install virtualenv wheel
 
 sudo /usr/bin/pip3 install wheel
 # Install all needed packages in a special wheel cache directory
 /usr/bin/pip3 wheel --wheel-dir "$HOME/python3-wheels" -r "${BASH_SOURCE%/*}/../common/shared/requirements.txt"
 
-# Install 3.8 compatible wheels
-python3.8 -m pip wheel --wheel-dir "$HOME/python3-wheels" -r "${BASH_SOURCE%/*}/../common/shared/requirements.txt"
+# Install compatible wheels
+python -m pip wheel --wheel-dir "$HOME/python3-wheels" -r "${BASH_SOURCE%/*}/../common/shared/requirements.txt"
+
+# Make FindPython3.cmake to find python3
+sudo ln -s /usr/bin/python3 /usr/local/bin/python3
 
 # shellcheck source=../common/unix/SetEnvVar.sh
 source "${BASH_SOURCE%/*}/../common/unix/SetEnvVar.sh"
@@ -182,4 +194,3 @@ SetEnvVar "PYTHON3_WHEEL_CACHE" "$HOME/python3-wheels"
 
 OpenSSLVersion="$(openssl version |cut -b 9-14)"
 echo "OpenSSL = $OpenSSLVersion" >> ~/versions.txt
-
